==> haskell-vector-algorithms-0.7.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vector-algorithms/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-150374d99b3855045b429cbe5d4e95da
key: vecto_3ip2TdjZtsUGqtZ79PwFCE
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
exposed-modules:
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-3ip2TdjZtsUGqtZ79PwFCE
include-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    primitive-0.6-e792418f7dbd95c8907334653976b3c4
    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.7.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vector-algorithms/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-35e55e2e8e51824728ed456b5a330a6b
key: vecto_0wekAXy6uoCFoww5dP6hc7
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
exposed-modules:
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-0wekAXy6uoCFoww5dP6hc7
include-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
